
<!-- README.md is generated from README.Rmd. Please edit that file -->

# `statspark`

<!-- badges: start -->

<!-- [![Build Status](https://travis-ci.org/joon3216/statspark.svg?branch=master)](https://travis-ci.org/joon3216/statspark) -->

<!-- [![codecov](https://codecov.io/gh/joon3216/statspark/branch/master/graph/badge.svg)](https://codecov.io/gh/joon3216/statspark)   -->

[![PyPI
pyversions](https://img.shields.io/pypi/pyversions/statspark.svg)](https://pypi.python.org/pypi/statspark/)  
[![PyPI version
shields.io](https://img.shields.io/pypi/v/statspark.svg)](https://pypi.python.org/pypi/statspark/)  
[![PyPI
status](https://img.shields.io/pypi/status/statspark.svg)](https://pypi.python.org/pypi/statspark/)  
<!-- badges: end -->

Functions for statistical analysis.

## Installation

To install, type:

``` bash
pip install statspark
```

To update, type:

``` bash
pip install statspark --upgrade
```
